@@ -26,6 +26,15 @@ Box of handy tools for Sphinx.
 #  OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
+# stdlib
+import sys
+
+# This all has to be up here so it's triggered first.
+if sys.version_info >= (3, 10):
+	# stdlib
+	import types
+	types.Union = types.UnionType
+
 # 3rd party
 from sphinx.application import Sphinx
 
@@ -48,7 +57,7 @@ from sphinx_toolbox.cache import cache  # noqa: F401
 __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020 Dominic Davis-Foster"
 __license__: str = "MIT License"
-__version__: str = "2.13.0"
+__version__: str = "2.14.1"
 __email__: str = "dominic@davis-foster.co.uk"
 
 __all__ = ["setup"]
