@@ -84,7 +84,7 @@ The changes are:
 API Reference
 -----------------
 
-"""  # noqa SXL001
+"""  # noqa: SXL001
 #
 #  Copyright (c) Alex Grönholm
 #  Changes copyright © 2020-2021 Dominic Davis-Foster <dominic@davis-foster.co.uk>
@@ -116,9 +116,10 @@ import operator
 import re
 import sys
 import types
+from contextlib import suppress
 from tempfile import TemporaryDirectory
 from types import FunctionType, ModuleType
-from typing import Any, AnyStr, Callable, Dict, List, Optional, Tuple, Type, TypeVar, get_type_hints
+from typing import Any, AnyStr, Callable, Dict, List, NewType, Optional, Tuple, Type, TypeVar, get_type_hints
 
 # 3rd party
 from domdf_python_tools.stringlist import DelimitedList
@@ -284,37 +285,47 @@ def format_annotation(annotation, fully_qualified: bool = False) -> str:
 		return "..."
 	elif annotation is itertools.cycle:
 		return f":func:`{prefix}itertools.cycle`"
-	elif annotation is types.GetSetDescriptorType:  # noqa E721
+	elif annotation is types.GetSetDescriptorType:  # noqa: E721
 		return f":py:data:`{prefix}types.GetSetDescriptorType`"
-	elif annotation is types.MemberDescriptorType:  # noqa E721
+	elif annotation is types.MemberDescriptorType:  # noqa: E721
 		return f":py:data:`{prefix}types.MemberDescriptorType`"
-	elif annotation is types.MappingProxyType:  # noqa E721
+	elif annotation is types.MappingProxyType:  # noqa: E721
 		return f":py:class:`{prefix}types.MappingProxyType`"
-	elif annotation is types.ModuleType:  # noqa E721
+	elif annotation is types.ModuleType:  # noqa: E721
 		return f":py:class:`{prefix}types.ModuleType`"
-	elif annotation is ClassMethodDescriptorType:  # noqa E721
-		return f":py:data:`{prefix}types.ClassMethodDescriptorType`"
-	elif annotation is MethodDescriptorType:  # noqa E721
-		return f":py:data:`{prefix}types.MethodDescriptorType`"
-	elif annotation is types.MethodType:  # noqa E721
-		return f":py:data:`{prefix}types.MethodType`"
-	elif annotation is MethodWrapperType:  # noqa E721
-		return f":py:data:`{prefix}types.MethodWrapperType`"
-	elif annotation is WrapperDescriptorType:  # noqa E721
-		return f":py:data:`{prefix}types.WrapperDescriptorType`"
-	elif annotation is types.BuiltinFunctionType:  # noqa E721
+	elif annotation is types.FunctionType:  # noqa: E721
+		return f":py:data:`{prefix}types.FunctionType`"
+	elif annotation is types.BuiltinFunctionType:  # noqa: E721
 		return f":py:data:`{prefix}types.BuiltinFunctionType`"
+	elif annotation is types.MethodType:  # noqa: E721
+		return f":py:data:`{prefix}types.MethodType`"
+	elif annotation is MethodDescriptorType:
+		return f":py:data:`{prefix}types.MethodDescriptorType`"
+	elif annotation is ClassMethodDescriptorType:
+		return f":py:data:`{prefix}types.ClassMethodDescriptorType`"
+	elif annotation is MethodWrapperType:
+		return f":py:data:`{prefix}types.MethodWrapperType`"
+	elif annotation is WrapperDescriptorType:
+		return f":py:data:`{prefix}types.WrapperDescriptorType`"
 	elif isinstance(annotation, ForwardRef):
 		# Unresolved forward ref
 		return f":py:obj:`{prefix}.{annotation.__forward_arg__}`"
-	elif annotation is type(re.compile('')):  # noqa E721
+	elif annotation is type(re.compile('')):  # noqa: E721
 		return f":py:class:`{prefix}typing.Pattern`"
-	elif annotation is TemporaryDirectory:  # noqa E721
+	elif annotation is TemporaryDirectory:
 		return f":py:obj:`{prefix}tempfile.TemporaryDirectory`"
+	elif sys.version_info >= (3, 10):
+		if annotation is types.UnionType:  # noqa: E721
+			return f":py:data:`{prefix}types.UnionType`"
 
 	try:
 		module = get_annotation_module(annotation)
 		class_name = get_annotation_class_name(annotation, module)
+
+		# Special case for typing.NewType being a class in 3.10
+		if sys.version_info >= (3, 10) and isinstance(annotation, NewType):
+			module, class_name = "typing", "NewType"
+
 		args = get_annotation_args(annotation, module, class_name)
 	except ValueError:
 		return f":py:obj:`~.{annotation}`"
@@ -334,23 +345,27 @@ def format_annotation(annotation, fully_qualified: bool = False) -> str:
 	formatted_args = ''
 
 	# Type variables are also handled specially
-	try:
+	with suppress(TypeError):
 		if isinstance(annotation, TypeVar) and annotation is not AnyStr:
 			if sys.version_info < (3, 7):
 				typevar_name = annotation.__name__
 			else:
 				typevar_name = (annotation.__module__ + '.' + annotation.__name__)
 			return f":py:data:`{repr(annotation)} <{typevar_name}>`"
-	except TypeError:
-		pass
 
 	# Some types require special handling
 	if full_name == "typing.NewType":
 		args_format = f"\\(:py:data:`~{annotation.__name__}`, {{}})"
-		role = "func"
+		role = "class" if sys.version_info > (3, 10) else "func"
 	elif full_name == "typing.Union" and len(args) == 2 and type(None) in args:
 		full_name = "typing.Optional"
 		args = tuple(x for x in args if x is not type(None))  # noqa: E721
+	elif full_name == "types.UnionType" and len(args) == 2 and type(None) in args:
+		full_name = "typing.Optional"
+		args = tuple(x for x in args if x is not type(None))  # noqa: E721
+	elif full_name == "types.UnionType":
+		full_name = "typing.Union"
+		role = "data"
 	elif full_name == "typing.Callable" and args and args[0] is not ...:
 		formatted_args = "\\[\\[" + ", ".join(format_annotation(arg) for arg in args[:-1]) + ']'
 		formatted_args += ", " + format_annotation(args[-1]) + ']'
